@@ -8,4 +8,12 @@ url <- "https://gnrsapi.xyz/gnrs_api.php" # public stable version
 #Bad URLs for testing
 
 #url <- "www.google.com"
-#url <- "www.hisstank.com"
\ No newline at end of file
+#url <- "www.hisstank.com"
+
+library("vcr") # *Required* as vcr is set up on loading
+
+invisible(vcr::vcr_configure(
+  dir = vcr::vcr_test_path("fixtures")
+))
+
+vcr::check_cassette_names()
